# aio-dprcon

A library and console client for DarkPlaces RCON protocol


## Installation

```bash
$ pip install aio-dprcon
```

To use the console tool on windows please also install pyreadline

```bash
$ pip install pyreadline
```

## Console tool usage

```bash
$ dprcon add  # Add a server
$ dprcon refresh SERVER_NAME  # Fill completion cache (optional)
$ dprcon connect SERVER_NAME  # Launch interactive RCON shell 
```

Or watch an ascii cast here - https://asciinema.org/a/148143

## Library API

To be written
